from werkzeug.exceptions import BadRequest

from flaschengeist.system.models.event import EventKind, Event
from sqlalchemy.exc import IntegrityError

from flaschengeist import logger
from flaschengeist.system.database import db


def create_event(begin, kind, end=None, description=None):
    try:
        event = Event(begin=begin,
                      end=end,
                      description=description,
                      kind=kind)
        db.session.add(event)
        db.session.commit()
        return event
    except IntegrityError:
        logger.debug("Database error when creating new event", exc_info=True)
        raise BadRequest


def create_event_kind(name):
    try:
        event = EventKind(name=name)
        db.session.add(event)
        db.session.commit()
        return event
    except IntegrityError:
        logger.debug("IntegrityError: Looks like there is a name collision", exc_info=True)
        raise BadRequest("Name already exists")
